@@ -1,5 +1,5 @@
 package Net::Kubernetes;
-$Net::Kubernetes::VERSION = '0.05';
+$Net::Kubernetes::VERSION = '0.06';
 use Moose;
 use Data::Dumper;
 require Net::Kubernetes::Namespace;
@@ -19,7 +19,9 @@ Net::Kubernetes
 
 =head1 VERSION
 
-version 0.05
+version 0.06
+
+This package provides an object oriented interface to the REST API's provided by kubernetes.
 
 =head1 SYNOPSIS
 
@@ -185,11 +187,9 @@ sub get_namespace {
 	if (! defined $namespace || ! length $namespace) {
 		Throwable::Error->throw(message=>'$namespace cannot be null');
 	}
-	print "Getting from ".$self->path.'/namespaces/'.$namespace."\n";
 	my $res = $self->ua->request($self->create_request(GET => $self->path.'/namespaces/'.$namespace));
 	if ($res->is_success) {
 		my $ns = $self->json->decode($res->content);
-		print Dumper($ns)."\n";
 		my(%create_args) = (url => $self->url, base_path=>$ns->{metadata}{selfLink}, namespace=> $namespace, _namespace_data=>$ns);
 		$create_args{username} = $self->username if(defined $self->username);
 		$create_args{password} = $self->password if(defined $self->password);
