@@ -1,9 +1,9 @@
 package Net::Kubernetes::Role::APIAccess;
-$Net::Kubernetes::Role::APIAccess::VERSION = '0.05';
+$Net::Kubernetes::Role::APIAccess::VERSION = '0.06';
 use Moose::Role;
 require LWP::UserAgent;
 require HTTP::Request;
-require JSON;
+require Cpanel::JSON::XS;
 require URI;
 use MIME::Base64;
 
@@ -13,7 +13,7 @@ Net::Kubernetes::Role::APIAccess
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =cut
 
@@ -59,7 +59,7 @@ has token => (
 
 has 'json' => (
     is       => 'ro',
-    isa      => 'JSON',
+    isa      => 'Cpanel::JSON::XS',
     required => 1,
     lazy     => 1,
     builder  => '_build_json',
@@ -98,7 +98,7 @@ sub _build_lwp_agent {
 }
 
 sub _build_json {
-    return JSON->new->allow_blessed(1)->convert_blessed(1);
+    return Cpanel::JSON::XS->new->allow_blessed(1)->convert_blessed(1);
 }
 
 sub create_request {
